.. SPDX-FileCopyrightText: 2025 Contributors to the OpenSTEF project <openstef@lfenergy.org>
..
.. SPDX-License-Identifier: MPL-2.0

Getting help
============

If you need assistance:

* 💬 **Slack**: Join the `LF Energy Slack workspace <https://slack.lfenergy.org/>`_ (#openstef channel)
* 🐛 **Issues**: Check `GitHub Issues <https://github.com/OpenSTEF/openstef/issues>`_ or create a new one
* 📧 **Email**: Contact us at ``openstef@lfenergy.org``
* 🤝 **Community meetings**: Join our four-weekly co-coding sessions

For more information, see our :doc:`/project/support` page.
